Learn R Programming

Fiscore (version 0.1.3)

Fi_score_region: Fi_score_region

Description

Function calculates combined Fi-score for a selected region; NOTE: some PDB files have breakages in their amino acid sequences and those values cannot be assessed. Moreover, values can be calculated either inclusively or not; include is set to FALSE by default

Usage

Fi_score_region(pdb_df, i, j, include = FALSE)

Arguments

pdb_df

Requires a PDB data frame generated by PDB_prepare

i

start residue for a region

j

end residue for a region

include

inclusive or not calculation, default FALSE

Value

Fi-score value

Examples

Run this code
# NOT RUN {
path_to_processed_PDB<- system.file("extdata", "pdb_df.tabular", package="Fiscore")
# basic usage of Fiscore_secondary
pdb_df<-read.table(path_to_processed_PDB)
Fi_score_region(pdb_df,900,925)
# }

Run the code above in your browser using DataLab